@@ -89,10 +89,11 @@ class Builtins(FluxCog):
       @self._commandeer(name="asif", parsed=False, default_auths=[Record.allow_all()])
       async def __asif(ctx: GuildMessageContext, args: str):
          """
-         asif <target>/{target} command args*
+         asif [type] <target>/{target} command args*
          ==
          Runs `command` as if it was being run by a `target` user, member, role, or permission-haver
          ==
+         type: [user/role/member/permissions/u/r/m/p] the type of `target`
          target: <user/member/role>/{perms}. Simulates usage by a given user, member, member with a role, or member that has a set of permissions. See s.ze.ax/perm for {perms} structure
          command: Name of the Command to run as `target`
          args: command arguments to pass to the Command
@@ -227,13 +228,6 @@ class Builtins(FluxCog):
          :param auth_ctx: Auth Context
          :return:
          """
-         print(f"Getting help! ctx: {ctx}")
-         print(type(ctx))
-         print(ctx.config_identifier)
-         print("auth")
-         print(auth_ctx)
-         print(auth_ctx.config_identifier)
-         print(type(auth_ctx))
          configs = self.flux.CONFIG.of(ctx)
          authorized_cmds: ty.Dict[str, Command] = {command.name: command for cog in self.flux.cogs for command in cog.commands if
                                                    Auth.accepts(auth_ctx, command) and command.name != "help"}
@@ -241,7 +235,8 @@ class Builtins(FluxCog):
          if not help_target:
             help_embed = discord.Embed(title=f"{utils.EMOJIS['question']} Command Help", description=f"{configs['prefix']}help <command> for more info")
             for cmd_name, command in authorized_cmds.items():
-               help_embed.add_field(name=cmd_name, value=f"{configs['prefix']}{command.short_usage}", inline=False)
+               usage = "\n".join([f"{configs['prefix']}{usage}" for usage in command.short_usage.split("\n")])
+               help_embed.add_field(name=cmd_name, value=usage, inline=False)
 
             return Response(embed=help_embed)
 
@@ -270,7 +265,7 @@ class Builtins(FluxCog):
          # print(cmd.long_usage)
          print(cmd.param_usage)
          for arg, detail in cmd.param_usage:
-            embed.add_field(name=arg, value=detail, inline=False)
+            embed.add_field(name=arg.strip(), value=detail.strip().replace("\\n", "\n"), inline=False)
             # embed.add_field(name=detail,value="", inline=False)
 
          # args, details = list(zip(*cmd.long_usage))
